/*
 * Copyright (c) 2020 Texas Instruments Incorporated - http://www.ti.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef BOARD_H
#define BOARD_H

//*****************************************************************************
//
// If building with a C++ compiler, make all of the definitions in this header
// have a C binding.
//
//*****************************************************************************
#ifdef __cplusplus
extern "C"
{
#endif

//
// Included Files
//

#include "driverlib.h"
#include "device.h"

//*****************************************************************************
//
// PinMux Configurations
//
//*****************************************************************************
//
// AIO225 - GPIO Settings
//
#define GPIO_PIN_AIO225 225
#define CAP_OVP_I_AIO_PIN_CONFIG GPIO_225_GPIO225
//
// AIO230 - GPIO Settings
//
#define GPIO_PIN_AIO230 230
#define SYNC_IN_I_AIO_PIN_CONFIG GPIO_230_GPIO230

//
// ANALOG -> myANALOGPinMux0 Pinmux
//

//
// EPWM1 -> myEPWM1 Pinmux
//
//
// EPWM1_A - GPIO Settings
//
#define GPIO_PIN_EPWM1_A 0
#define myEPWM1_EPWMA_GPIO 0
#define myEPWM1_EPWMA_PIN_CONFIG GPIO_0_EPWM1_A
//
// EPWM1_B - GPIO Settings
//
#define GPIO_PIN_EPWM1_B 1
#define myEPWM1_EPWMB_GPIO 1
#define myEPWM1_EPWMB_PIN_CONFIG GPIO_1_EPWM1_B

//
// EPWM2 -> myEPWM2 Pinmux
//
//
// EPWM2_A - GPIO Settings
//
#define GPIO_PIN_EPWM2_A 2
#define myEPWM2_EPWMA_GPIO 2
#define myEPWM2_EPWMA_PIN_CONFIG GPIO_2_EPWM2_A
//
// EPWM2_B - GPIO Settings
//
#define GPIO_PIN_EPWM2_B 3
#define myEPWM2_EPWMB_GPIO 3
#define myEPWM2_EPWMB_PIN_CONFIG GPIO_3_EPWM2_B

//
// EPWM3 -> myEPWM3 Pinmux
//
//
// EPWM3_A - GPIO Settings
//
#define GPIO_PIN_EPWM3_A 4
#define myEPWM3_EPWMA_GPIO 4
#define myEPWM3_EPWMA_PIN_CONFIG GPIO_4_EPWM3_A
//
// EPWM3_B - GPIO Settings
//
#define GPIO_PIN_EPWM3_B 5
#define myEPWM3_EPWMB_GPIO 5
#define myEPWM3_EPWMB_PIN_CONFIG GPIO_5_EPWM3_B

//
// EPWM4 -> myEPWM4 Pinmux
//
//
// EPWM4_A - GPIO Settings
//
#define GPIO_PIN_EPWM4_A 22
#define myEPWM4_EPWMA_GPIO 22
#define myEPWM4_EPWMA_PIN_CONFIG GPIO_22_EPWM4_A
//
// EPWM4_B - GPIO Settings
//
#define GPIO_PIN_EPWM4_B 23
#define myEPWM4_EPWMB_GPIO 23
#define myEPWM4_EPWMB_PIN_CONFIG GPIO_23_EPWM4_B
//
// GPIO40 - GPIO Settings
//
#define DEBUG0_GPIO_PIN_CONFIG GPIO_40_GPIO40
//
// GPIO41 - GPIO Settings
//
#define EXT_WATCHDOG_GPIO_PIN_CONFIG GPIO_41_GPIO41
//
// GPIO7 - GPIO Settings
//
#define SYNC_I_GPIO_PIN_CONFIG GPIO_7_GPIO7
//
// GPIO8 - GPIO Settings
//
#define HW_IMB_I_GPIO_PIN_CONFIG GPIO_8_GPIO8
//
// GPIO10 - GPIO Settings
//
#define OCP_I_GPIO_PIN_CONFIG GPIO_10_GPIO10
//
// GPIO28 - GPIO Settings
//
#define OVP_I_GPIO_PIN_CONFIG GPIO_28_GPIO28
//
// GPIO11 - GPIO Settings
//
#define ISHARE_PROTECT_GPIO_PIN_CONFIG GPIO_11_GPIO11
//
// GPIO29 - GPIO Settings
//
#define FAN_TACH0_GPIO_PIN_CONFIG GPIO_29_GPIO29
//
// GPIO24 - GPIO Settings
//
#define DEBUG1_GPIO_PIN_CONFIG GPIO_24_GPIO24
//
// GPIO23 - GPIO Settings
//
#define EXT_WDT_FAULT_GPIO_PIN_CONFIG GPIO_23_GPIO23

//
// I2CA -> myI2C0 Pinmux
//
//
// I2CA_SDA - GPIO Settings
//
#define GPIO_PIN_I2CA_SDA 32
#define myI2C0_I2CSDA_GPIO 32
#define myI2C0_I2CSDA_PIN_CONFIG GPIO_32_I2CA_SDA
//
// I2CA_SCL - GPIO Settings
//
#define GPIO_PIN_I2CA_SCL 33
#define myI2C0_I2CSCL_GPIO 33
#define myI2C0_I2CSCL_PIN_CONFIG GPIO_33_I2CA_SCL

//
// SCIA -> mySCI0 Pinmux
//
//
// SCIA_RX - GPIO Settings
//
#define GPIO_PIN_SCIA_RX 17
#define mySCI0_SCIRX_GPIO 17
#define mySCI0_SCIRX_PIN_CONFIG GPIO_17_SCIA_RX
//
// SCIA_TX - GPIO Settings
//
#define GPIO_PIN_SCIA_TX 16
#define mySCI0_SCITX_GPIO 16
#define mySCI0_SCITX_PIN_CONFIG GPIO_16_SCIA_TX

//
// SCIB -> mySCI1 Pinmux
//
//
// SCIB_RX - GPIO Settings
//
#define GPIO_PIN_SCIB_RX 13
#define mySCI1_SCIRX_GPIO 13
#define mySCI1_SCIRX_PIN_CONFIG GPIO_13_SCIB_RX
//
// SCIB_TX - GPIO Settings
//
#define GPIO_PIN_SCIB_TX 12
#define mySCI1_SCITX_GPIO 12
#define mySCI1_SCITX_PIN_CONFIG GPIO_12_SCIB_TX

//*****************************************************************************
//
// ADC Configurations
//
//*****************************************************************************
#define myADC0_BASE ADCA_BASE
#define myADC0_RESULT_BASE ADCARESULT_BASE
#define myADC0_SOC0 ADC_SOC_NUMBER0
#define myADC0_FORCE_SOC0 ADC_FORCE_SOC0
#define myADC0_SAMPLE_WINDOW_SOC0 300
#define myADC0_TRIGGER_SOURCE_SOC0 ADC_TRIGGER_SW_ONLY
#define myADC0_CHANNEL_SOC0 ADC_CH_ADCIN6
#define myADC0_SOC1 ADC_SOC_NUMBER1
#define myADC0_FORCE_SOC1 ADC_FORCE_SOC1
#define myADC0_SAMPLE_WINDOW_SOC1 300
#define myADC0_TRIGGER_SOURCE_SOC1 ADC_TRIGGER_SW_ONLY
#define myADC0_CHANNEL_SOC1 ADC_CH_ADCIN6
#define myADC0_SOC2 ADC_SOC_NUMBER2
#define myADC0_FORCE_SOC2 ADC_FORCE_SOC2
#define myADC0_SAMPLE_WINDOW_SOC2 300
#define myADC0_TRIGGER_SOURCE_SOC2 ADC_TRIGGER_SW_ONLY
#define myADC0_CHANNEL_SOC2 ADC_CH_ADCIN6
#define myADC0_SOC3 ADC_SOC_NUMBER3
#define myADC0_FORCE_SOC3 ADC_FORCE_SOC3
#define myADC0_SAMPLE_WINDOW_SOC3 300
#define myADC0_TRIGGER_SOURCE_SOC3 ADC_TRIGGER_SW_ONLY
#define myADC0_CHANNEL_SOC3 ADC_CH_ADCIN6
#define myADC0_SOC4 ADC_SOC_NUMBER4
#define myADC0_FORCE_SOC4 ADC_FORCE_SOC4
#define myADC0_SAMPLE_WINDOW_SOC4 300
#define myADC0_TRIGGER_SOURCE_SOC4 ADC_TRIGGER_SW_ONLY
#define myADC0_CHANNEL_SOC4 ADC_CH_ADCIN6
void myADC0_init();

#define myADC1_BASE ADCB_BASE
#define myADC1_RESULT_BASE ADCBRESULT_BASE
#define myADC1_SOC0 ADC_SOC_NUMBER0
#define myADC1_FORCE_SOC0 ADC_FORCE_SOC0
#define myADC1_SAMPLE_WINDOW_SOC0 833.3333333333334
#define myADC1_TRIGGER_SOURCE_SOC0 ADC_TRIGGER_EPWM4_SOCA
#define myADC1_CHANNEL_SOC0 ADC_CH_ADCIN0
#define myADC1_SOC1 ADC_SOC_NUMBER1
#define myADC1_FORCE_SOC1 ADC_FORCE_SOC1
#define myADC1_SAMPLE_WINDOW_SOC1 833.3333333333334
#define myADC1_TRIGGER_SOURCE_SOC1 ADC_TRIGGER_EPWM4_SOCA
#define myADC1_CHANNEL_SOC1 ADC_CH_ADCIN0
#define myADC1_SOC2 ADC_SOC_NUMBER2
#define myADC1_FORCE_SOC2 ADC_FORCE_SOC2
#define myADC1_SAMPLE_WINDOW_SOC2 833.3333333333334
#define myADC1_TRIGGER_SOURCE_SOC2 ADC_TRIGGER_EPWM4_SOCA
#define myADC1_CHANNEL_SOC2 ADC_CH_ADCIN2
#define myADC1_SOC3 ADC_SOC_NUMBER3
#define myADC1_FORCE_SOC3 ADC_FORCE_SOC3
#define myADC1_SAMPLE_WINDOW_SOC3 833.3333333333334
#define myADC1_TRIGGER_SOURCE_SOC3 ADC_TRIGGER_EPWM4_SOCA
#define myADC1_CHANNEL_SOC3 ADC_CH_ADCIN3
#define myADC1_SOC4 ADC_SOC_NUMBER4
#define myADC1_FORCE_SOC4 ADC_FORCE_SOC4
#define myADC1_SAMPLE_WINDOW_SOC4 833.3333333333334
#define myADC1_TRIGGER_SOURCE_SOC4 ADC_TRIGGER_EPWM4_SOCA
#define myADC1_CHANNEL_SOC4 ADC_CH_ADCIN6
#define myADC1_SOC5 ADC_SOC_NUMBER5
#define myADC1_FORCE_SOC5 ADC_FORCE_SOC5
#define myADC1_SAMPLE_WINDOW_SOC5 833.3333333333334
#define myADC1_TRIGGER_SOURCE_SOC5 ADC_TRIGGER_EPWM4_SOCA
#define myADC1_CHANNEL_SOC5 ADC_CH_ADCIN9
#define myADC1_SOC6 ADC_SOC_NUMBER6
#define myADC1_FORCE_SOC6 ADC_FORCE_SOC6
#define myADC1_SAMPLE_WINDOW_SOC6 833.3333333333334
#define myADC1_TRIGGER_SOURCE_SOC6 ADC_TRIGGER_EPWM4_SOCA
#define myADC1_CHANNEL_SOC6 ADC_CH_ADCIN14
#define myADC1_SOC7 ADC_SOC_NUMBER7
#define myADC1_FORCE_SOC7 ADC_FORCE_SOC7
#define myADC1_SAMPLE_WINDOW_SOC7 833.3333333333334
#define myADC1_TRIGGER_SOURCE_SOC7 ADC_TRIGGER_EPWM4_SOCA
#define myADC1_CHANNEL_SOC7 ADC_CH_ADCIN12
void myADC1_init();

#define myADC2_BASE ADCC_BASE
#define myADC2_RESULT_BASE ADCCRESULT_BASE
#define myADC2_SOC0 ADC_SOC_NUMBER0
#define myADC2_FORCE_SOC0 ADC_FORCE_SOC0
#define myADC2_SAMPLE_WINDOW_SOC0 250.00000000000003
#define myADC2_TRIGGER_SOURCE_SOC0 ADC_TRIGGER_EPWM1_SOCA
#define myADC2_CHANNEL_SOC0 ADC_CH_ADCIN1
#define myADC2_SOC1 ADC_SOC_NUMBER1
#define myADC2_FORCE_SOC1 ADC_FORCE_SOC1
#define myADC2_SAMPLE_WINDOW_SOC1 100
#define myADC2_TRIGGER_SOURCE_SOC1 ADC_TRIGGER_EPWM1_SOCA
#define myADC2_CHANNEL_SOC1 ADC_CH_ADCIN1
#define myADC2_SOC2 ADC_SOC_NUMBER2
#define myADC2_FORCE_SOC2 ADC_FORCE_SOC2
#define myADC2_SAMPLE_WINDOW_SOC2 833.3333333333334
#define myADC2_TRIGGER_SOURCE_SOC2 ADC_TRIGGER_EPWM1_SOCA
#define myADC2_CHANNEL_SOC2 ADC_CH_ADCIN1
#define myADC2_SOC3 ADC_SOC_NUMBER3
#define myADC2_FORCE_SOC3 ADC_FORCE_SOC3
#define myADC2_SAMPLE_WINDOW_SOC3 833.3333333333334
#define myADC2_TRIGGER_SOURCE_SOC3 ADC_TRIGGER_EPWM1_SOCA
#define myADC2_CHANNEL_SOC3 ADC_CH_ADCIN1
#define myADC2_SOC4 ADC_SOC_NUMBER4
#define myADC2_FORCE_SOC4 ADC_FORCE_SOC4
#define myADC2_SAMPLE_WINDOW_SOC4 100
#define myADC2_TRIGGER_SOURCE_SOC4 ADC_TRIGGER_EPWM1_SOCA
#define myADC2_CHANNEL_SOC4 ADC_CH_ADCIN1
#define myADC2_SOC5 ADC_SOC_NUMBER5
#define myADC2_FORCE_SOC5 ADC_FORCE_SOC5
#define myADC2_SAMPLE_WINDOW_SOC5 100
#define myADC2_TRIGGER_SOURCE_SOC5 ADC_TRIGGER_EPWM1_SOCA
#define myADC2_CHANNEL_SOC5 ADC_CH_ADCIN0
#define myADC2_SOC6 ADC_SOC_NUMBER6
#define myADC2_FORCE_SOC6 ADC_FORCE_SOC6
#define myADC2_SAMPLE_WINDOW_SOC6 100
#define myADC2_TRIGGER_SOURCE_SOC6 ADC_TRIGGER_EPWM1_SOCA
#define myADC2_CHANNEL_SOC6 ADC_CH_ADCIN0
#define myADC2_SOC7 ADC_SOC_NUMBER7
#define myADC2_FORCE_SOC7 ADC_FORCE_SOC7
#define myADC2_SAMPLE_WINDOW_SOC7 100
#define myADC2_TRIGGER_SOURCE_SOC7 ADC_TRIGGER_EPWM1_SOCA
#define myADC2_CHANNEL_SOC7 ADC_CH_ADCIN0
#define myADC2_SOC8 ADC_SOC_NUMBER8
#define myADC2_FORCE_SOC8 ADC_FORCE_SOC8
#define myADC2_SAMPLE_WINDOW_SOC8 100
#define myADC2_TRIGGER_SOURCE_SOC8 ADC_TRIGGER_EPWM1_SOCA
#define myADC2_CHANNEL_SOC8 ADC_CH_ADCIN0
void myADC2_init();


//*****************************************************************************
//
// AIO Configurations
//
//*****************************************************************************
#define CAP_OVP_I 225
void CAP_OVP_I_init();
#define SYNC_IN_I 230
void SYNC_IN_I_init();

//*****************************************************************************
//
// ASYSCTL Configurations
//
//*****************************************************************************

//*****************************************************************************
//
// CMPSS Configurations
//
//*****************************************************************************
#define myCMPSS0_BASE CMPSS1_BASE
#define myCMPSS0_HIGH_COMP_BASE CMPSS1_BASE    
#define myCMPSS0_LOW_COMP_BASE CMPSS1_BASE    
void myCMPSS0_init();

//*****************************************************************************
//
// CPUTIMER Configurations
//
//*****************************************************************************
#define myCPUTIMER0_BASE CPUTIMER0_BASE
void myCPUTIMER0_init();
#define myCPUTIMER1_BASE CPUTIMER1_BASE
void myCPUTIMER1_init();

//*****************************************************************************
//
// DAC Configurations
//
//*****************************************************************************
#define myDAC0_BASE DACA_BASE
void myDAC0_init();

//*****************************************************************************
//
// ECAP Configurations
//
//*****************************************************************************
#define ECAP0_FAN_CAPTURE_BASE ECAP1_BASE
void ECAP0_FAN_CAPTURE_init();

//*****************************************************************************
//
// EPWM Configurations
//
//*****************************************************************************
#define myEPWM1_BASE EPWM1_BASE
#define myEPWM1_TBPRD 1600
#define myEPWM1_COUNTER_MODE EPWM_COUNTER_MODE_UP
#define myEPWM1_TBPHS 0
#define myEPWM1_CMPA 1574
#define myEPWM1_CMPB 25
#define myEPWM1_CMPC 0
#define myEPWM1_CMPD 0
#define myEPWM1_DBRED 3144
#define myEPWM1_DBFED 48
#define myEPWM1_TZA_ACTION EPWM_TZ_ACTION_LOW
#define myEPWM1_TZB_ACTION EPWM_TZ_ACTION_LOW
#define myEPWM1_OSHT_SOURCES (EPWM_TZ_SIGNAL_DCAEVT1 | EPWM_TZ_SIGNAL_DCBEVT1 | EPWM_TZ_SIGNAL_OSHT1)
#define myEPWM1_INTERRUPT_SOURCE EPWM_INT_TBCTR_ZERO
#define myEPWM2_BASE EPWM2_BASE
#define myEPWM2_TBPRD 1600
#define myEPWM2_COUNTER_MODE EPWM_COUNTER_MODE_UP
#define myEPWM2_TBPHS 0
#define myEPWM2_CMPA 1574
#define myEPWM2_CMPB 25
#define myEPWM2_CMPC 0
#define myEPWM2_CMPD 0
#define myEPWM2_DBRED 3144
#define myEPWM2_DBFED 48
#define myEPWM2_TZA_ACTION EPWM_TZ_ACTION_LOW
#define myEPWM2_TZB_ACTION EPWM_TZ_ACTION_LOW
#define myEPWM2_OSHT_SOURCES (EPWM_TZ_SIGNAL_DCAEVT1 | EPWM_TZ_SIGNAL_DCBEVT1 | EPWM_TZ_SIGNAL_OSHT1)
#define myEPWM2_INTERRUPT_SOURCE EPWM_INT_TBCTR_DISABLED
#define myEPWM3_BASE EPWM3_BASE
#define myEPWM3_TBPRD 1600
#define myEPWM3_COUNTER_MODE EPWM_COUNTER_MODE_UP
#define myEPWM3_TBPHS 0
#define myEPWM3_CMPA 1574
#define myEPWM3_CMPB 25
#define myEPWM3_CMPC 0
#define myEPWM3_CMPD 0
#define myEPWM3_DBRED 3144
#define myEPWM3_DBFED 48
#define myEPWM3_TZA_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM3_TZB_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM3_OSHT_SOURCES (EPWM_TZ_SIGNAL_DCAEVT1 | EPWM_TZ_SIGNAL_DCBEVT1 | EPWM_TZ_SIGNAL_OSHT1)
#define myEPWM3_INTERRUPT_SOURCE EPWM_INT_TBCTR_DISABLED
#define myEPWM4_BASE EPWM4_BASE
#define myEPWM4_TBPRD 1250
#define myEPWM4_COUNTER_MODE EPWM_COUNTER_MODE_UP
#define myEPWM4_TBPHS 0
#define myEPWM4_CMPA 100
#define myEPWM4_CMPB 50
#define myEPWM4_CMPC 0
#define myEPWM4_CMPD 0
#define myEPWM4_DBRED 0
#define myEPWM4_DBFED 0
#define myEPWM4_TZA_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM4_TZB_ACTION EPWM_TZ_ACTION_HIGH_Z
#define myEPWM4_INTERRUPT_SOURCE EPWM_INT_TBCTR_DISABLED

//*****************************************************************************
//
// EPWMXBAR Configurations
//
//*****************************************************************************
void myEPWMXBAR0_init();
#define myEPWMXBAR0 XBAR_TRIP4
#define myEPWMXBAR0_ENABLED_MUXES (XBAR_MUX00)

//*****************************************************************************
//
// GPIO Configurations
//
//*****************************************************************************
#define DEBUG0 40
void DEBUG0_init();
#define EXT_WATCHDOG 41
void EXT_WATCHDOG_init();
#define SYNC_I 7
void SYNC_I_init();
#define HW_IMB_I 8
void HW_IMB_I_init();
#define OCP_I 10
void OCP_I_init();
#define OVP_I 28
void OVP_I_init();
#define ISHARE_PROTECT 11
void ISHARE_PROTECT_init();
#define FAN_TACH0 29
void FAN_TACH0_init();
#define DEBUG1 24
void DEBUG1_init();
#define EXT_WDT_FAULT 23
void EXT_WDT_FAULT_init();

//*****************************************************************************
//
// I2C Configurations
//
//*****************************************************************************
#define myI2C0_BASE I2CA_BASE
#define myI2C0_BITRATE 400000
#define myI2C0_TARGET_ADDRESS 0
#define myI2C0_OWN_TARGET_ADDRESS 95
void myI2C0_init();

//*****************************************************************************
//
// INPUTXBAR Configurations
//
//*****************************************************************************
#define INPUTXBAR_OVP_SOURCE 28
#define INPUTXBAR_OVP_INPUT XBAR_INPUT1
void INPUTXBAR_OVP_init();
#define INPUTXBAR_FANTACH0_SOURCE 29
#define INPUTXBAR_FANTACH0_INPUT XBAR_INPUT7
void INPUTXBAR_FANTACH0_init();
#define INPUTXBAR_OCP_SOURCE 10
#define INPUTXBAR_OCP_INPUT XBAR_INPUT4
void INPUTXBAR_OCP_init();

//*****************************************************************************
//
// INTERRUPT Configurations
//
//*****************************************************************************

// Interrupt Settings for INT_myEPWM1
#define INT_myEPWM1 INT_EPWM1
#define INT_myEPWM1_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP3
extern __interrupt void epwm1_ISR(void);

// Interrupt Settings for INT_OCP_I_XINT
#define INT_OCP_I_XINT INT_XINT1
#define INT_OCP_I_XINT_INTERRUPT_ACK_GROUP INTERRUPT_ACK_GROUP1
extern __interrupt void ocp_ISR(void);

//*****************************************************************************
//
// SCI Configurations
//
//*****************************************************************************
#define mySCI0_BASE SCIA_BASE
#define mySCI0_BAUDRATE 19231
#define mySCI0_CONFIG_WLEN SCI_CONFIG_WLEN_8
#define mySCI0_CONFIG_STOP SCI_CONFIG_STOP_ONE
#define mySCI0_CONFIG_PAR SCI_CONFIG_PAR_NONE
void mySCI0_init();
#define mySCI1_BASE SCIB_BASE
#define mySCI1_BAUDRATE 115200
#define mySCI1_CONFIG_WLEN SCI_CONFIG_WLEN_8
#define mySCI1_CONFIG_STOP SCI_CONFIG_STOP_ONE
#define mySCI1_CONFIG_PAR SCI_CONFIG_PAR_NONE
void mySCI1_init();

//*****************************************************************************
//
// SYNC Scheme Configurations
//
//*****************************************************************************

//*****************************************************************************
//
// WATCHDOG Configurations
//
//*****************************************************************************
#define myWATCHDOG0_PREDIVIDER SYSCTL_WD_PREDIV_512
#define myWATCHDOG0_PRESCALAR SYSCTL_WD_PRESCALE_8
void myWATCHDOG0_init();

//*****************************************************************************
//
// XINT Configurations
//
//*****************************************************************************
#define OCP_I_XINT GPIO_INT_XINT1
#define OCP_I_XINT_TYPE GPIO_INT_TYPE_FALLING_EDGE
void OCP_I_XINT_init();

//*****************************************************************************
//
// Board Configurations
//
//*****************************************************************************
void	Board_init();
void	ADC_init();
void	AIO_init();
void	ASYSCTL_init();
void	CMPSS_init();
void	CPUTIMER_init();
void	DAC_init();
void	ECAP_init();
void	EPWM_init();
void	EPWMXBAR_init();
void	GPIO_init();
void	I2C_init();
void	INPUTXBAR_init();
void	INTERRUPT_init();
void	SCI_init();
void	SYNC_init();
void	WATCHDOG_init();
void	XINT_init();
void	PinMux_init();

//*****************************************************************************
//
// Mark the end of the C bindings section for C++ compilers.
//
//*****************************************************************************
#ifdef __cplusplus
}
#endif

#endif  // end of BOARD_H definition
