/*
 * analog.h
 *
 *  Created on: Apr 4, 2023
 *      Author: fireb
 */

#ifndef ANALOG_H_
#define ANALOG_H_

// !!! we ignore first conversion
// ADC A channels
#define VOUT_SENSE_H_ADC    (HWREGH(ADCARESULT_BASE+1))     // A6
#define VOUT_SENSE1_H_ADC   (HWREGH(ADCARESULT_BASE+2))     // A6
#define VOUT_SENSE2_H_ADC   (HWREGH(ADCARESULT_BASE+3))     // A6
#define VOUT_SENSE3_H_ADC   (HWREGH(ADCARESULT_BASE+4))     // A6

// ADC B channels
#define VCAP_SENSE_ADC      (HWREGH(ADCBRESULT_BASE+1))     // B0
#define IOUT1_SENSE_ADC     (HWREGH(ADCBRESULT_BASE+2))     // B2
#define IOUT2_SENSE_ADC     (HWREGH(ADCBRESULT_BASE+3))     // B3
#define IOUT3_SENSE_ADC     (HWREGH(ADCBRESULT_BASE+4))     // B6
#define T1_SENSE_ADC        (HWREGH(ADCBRESULT_BASE+5))     // B9
#define T2_SENSE_ADC        (HWREGH(ADCBRESULT_BASE+6))     // B14
#define T3_SENSE_ADC        (HWREGH(ADCBRESULT_BASE+7))     // B12

// ADC C Channels
#define IOUT_SENSE_ADC      (HWREGH(ADCCRESULT_BASE+1))     // C1
#define IOUT_SENSE1_ADC     (HWREGH(ADCCRESULT_BASE+2))     // C1
#define IOUT_SENSE2_ADC     (HWREGH(ADCCRESULT_BASE+3))     // C1
#define IOUT_SENSE3_ADC     (HWREGH(ADCCRESULT_BASE+4))     // C1

#define ISHARE_SENSE_ADC    (HWREGH(ADCCRESULT_BASE+5))     // C0
#define ISHARE_SENSE1_ADC   (HWREGH(ADCCRESULT_BASE+6))     // C0
#define ISHARE_SENSE2_ADC   (HWREGH(ADCCRESULT_BASE+7))     // C0
#define ISHARE_SENSE3_ADC   (HWREGH(ADCCRESULT_BASE+8))     // C0


#ifdef HPT5K_48V
#define ADC_VSENSE_FS           (59l)     // Nominal FS voltage reading
#define ADC_ISENSE_FS           (133l)
#define ADC_ISENSEX_FS          (44l)

#elif HPT5K_60V
#define ADC_VSENSE_FS           (74l)        // Nominal FS voltage reading
#define ADC_ISENSE_FS           (107l)
#define ADC_ISENSEX_FS          (36l)        // 35.66A

#elif HPT5K_80V
#define ADC_VSENSE_FS           (98l)        // Nominal FS voltage reading
#define ADC_ISENSE_FS           (80l)
#define ADC_ISENSEX_FS          (27l)

#elif HPT5K_100V
#define ADC_VSENSE_FS           (123l)       // Nominal FS voltage reading
#define ADC_ISENSE_FS           (64l)
#define ADC_ISENSEX_FS          (21l)        // 21.32A

#elif HPT5K_200V
#define ADC_VSENSE_FS           (246l)       // Nominal FS voltage reading
#define ADC_ISENSE_FS           (32l)
#define ADC_ISENSEX_FS          (11l)        // 10.66A

#elif HPT5K_400V
#define ADC_VSENSE_FS           (502l)       // Nominal FS voltage reading
#define ADC_ISENSE_FS           (16l)
#define ADC_ISENSEX_FS          (6l)        // ??A

#elif HPT5K_800V
#define ADC_VSENSE_FS           (989l)       // Nominal FS voltage reading
#define ADC_ISENSE_FS           (8l)
#define ADC_ISENSEX_FS          (3l)        // ??A
#endif


// Output Voltage
#define ADC_VSENSE_CNT_FS               (32760l)    // Readings are * 8 or shift left 3 to Q15 format
#define ADC_VSENSE_RVU_FS               (ADC_VSENSE_FS * RVU)
#define RVU_TO_VSENSE_COUNT(rvu)        ((((int32_t)rvu) * ADC_VSENSE_CNT_FS) / ADC_VSENSE_RVU_FS)
#define VSENSE_COUNT_TO_RVU(cnt)        (((int32_t)cnt * ADC_VSENSE_RVU_FS) / ADC_VSENSE_CNT_FS)
#define VSENSE_TO_COUNT(v)              ((((int32_t)v) * ADC_VSENSE_CNT_FS) / ADC_VSENSE_FS)
#define VOUT_PERCENTAGE_TO_COUNT(x)     (int32_t)((((int64_t)x) * MFR_VOUT_NOMINAL * ADC_VSENSE_CNT_FS) / (ADC_VSENSE_FS * 100l))
#define VOUT_PERCENTAGE_TO_RVU(x)       ((((int32_t)x) * MFR_VOUT_NOMINAL * RVU) / 100l)

// Total Current Sense
#define ADC_ISENSE_CNT_FS               (32760)    // Readings are * 8 or shift left 3
#define ADC_ISENSE_RVI_FS               (ADC_ISENSE_FS * RVI)       // IOUT_SENSE and ISHARE_IN in A*32
#define RVI_TO_ISENSE_COUNT(rvi)        (((int32_t)rvi * ADC_ISENSE_CNT_FS) / ADC_ISENSE_RVI_FS)
#define ISENSE_COUNT_TO_RVI(cnt)        (((int32_t)cnt * ADC_ISENSE_RVI_FS) / ADC_ISENSE_CNT_FS)
#define ISENSE_TO_COUNT(i)              ((((int32_t)i) * ADC_ISENSE_CNT_FS) / ADC_ISENSE_FS)
#define ISENSE_PERCENTAGE_TO_COUNT(i)   ((((int32_t)i) * ADC_ISENSE_CNT_FS)/100)
#define IOUT_TO_RVI(i)                  (((int32_t)i) * RVI)
#define IOUT_PERCENTAGE_TO_RVI(i)       ((((int32_t)i) * MFR_IOUT_NOMINAL * RVI) / 100)
#define IOUT_PERCENTAGE_TO_COUNT(i)     ((((int32_t)i) * MFR_IOUT_NOMINAL * ADC_ISENSE_CNT_FS) / (ADC_ISENSE_FS * 100))

#define MAX_HL_CAPACITY_IN_AMPS         (MFR_IOUT_MAX)
#define NOM_HL_CAPACITY_IN_AMPS         (MFR_IOUT_NOMINAL)
//#define CURRENT_SOFT_START_START        ISENSE_TO_COUNT(NOM_HL_CAPACITY_IN_AMPS / 4l)  // ~ around 25% load
#define CL_IN_VOLTAGE_SOFT_START        ISENSE_PERCENTAGE_TO_COUNT(99)  // 99%

// Channel X Current Sense
#define ADC_ISENSEX_CNT_FS              (32760)
#define IOUTX_PERCENTAGE_TO_RVI(i)      ((((int32_t)i) * ADC_ISENSEX_FS * RVI) / 100l)
#define ISENSEX_PERCENTAGE_TO_COUNT(i)  ((((int32_t)i) * ADC_ISENSEX_CNT_FS) / 100l)


#define ADC_CNT_FS                      (0x7FF8)

typedef struct
{
    uint16_t vout_raw;
    int16_t vout_h_filt;
    int16_t vout_pot_adj_filt;
    int16_t vprog_filt;

    int16_t vcmd_ref;
    int16_t u_ref;
    int16_t target;
    int16_t v_min;
    int16_t v_max;
    int16_t  vout_pot_adj;

    uint16_t Kp;
    uint16_t Ki;
    uint16_t Kp_walkin;
    uint16_t Ki_walkin;
    uint16_t Kp_active;
    uint16_t Ki_active;

    int32_t  int0;
    int32_t  v_ctrl_full;

    int16_t vout_h_fast_filt;
    int16_t vout_pot_adj_raw;

    uint16_t Kd_active;
    uint16_t Kd;
    uint16_t Ka_active;     // derivative low pass filter

    int32_t verr_delta;
    int32_t verr_z1;

    int32_t vcap_sense;
} voltage_t;

typedef struct
{
    int16_t iout_filt;
    int16_t iout1_filt;
    int16_t iout2_filt;
    int16_t iout3_filt;
    int16_t ishare_filt;
    int16_t iprog_filt;

    int16_t iset_ref;
    int16_t i_ref;
    int16_t iset_ref_max;

    uint16_t iout_rvi_cal;
    uint16_t iout_rvi_cal1;
    uint16_t iout_rvi_cal2;
    uint16_t iout_rvi_cal3;

    int16_t ishare_rvi_cal;

    int16_t hiline_max;

    uint16_t Kp;
    uint16_t Ki;
    uint16_t Kp_walkin;
    uint16_t Ki_walkin;
    uint16_t Kp_active;
    uint16_t Ki_active;
    int32_t int0;
    int32_t i_ctrl_full;

    int16_t walkin_step;    // TBD, not used
    int16_t i_walkin;       // TBD not used

    int16_t active_step_up;

    int16_t  previous_reading;
    int16_t internal_ishare;
    int16_t iout_max;
    int16_t iout_filt2;
    int32_t iprog_gain;

    uint16_t pout;
    int16_t iout_max_filt;
    int16_t iout_adc_z1;

    volatile int32_t iout_raw;
    int32_t  ishare_raw;
} current_t;

typedef struct
{
    int16_t ambient_c;

    int16_t temp1_filt;
    int16_t temp2_filt;
    int16_t temp3_filt;

    int16_t temp1_c;
    int16_t temp2_c;
    int16_t temp3_c;
} temperature_t;

// filter for iout
#define FILTER_IOUT_POLE    0x02                    // RC pole
#define FILTER_IOUT_GAIN    0x02                    // scale up
#define FILTER_IOUT_SCALE   (FILTER_IOUT_POLE + FILTER_IOUT_GAIN)

#define FILTERA_POLE        0x06                    // RC pole
#define FILTERA_GAIN        0x02                    // scale up
#define FILTERA_SCALE       (FILTERA_POLE + FILTERA_GAIN)

#define FILTER_VOUT_FAST_POLE   0x02                // RC pole
#define FILTER_VOUT_FAST_GAIN   0x02                // scale up
#define FILTER_VOUT_FAST_SCALE  (FILTER_VOUT_FAST_POLE + FILTER_VOUT_FAST_GAIN)

// filter for temperature sensors
#define FILTER_TEMP_POLE    0x06                    // RC pole
#define FILTER_TEMP_GAIN    0x02                    // scale up
#define FILTER_TEMP_SCALE   0x05   //(FILTER_TEMP_POLE + FILTER_TEMP_GAIN)

// filter for IPROG input
#define FILTER_IPROG_POLE   0x03                    // RC pole
#define FILTER_IPROG_GAIN   0x02                    // scale up
#define FILTER_IPROG_SCALE  2 //(FILTER_IPROG_POLE + FILTER_IPROG_GAIN)

// filter for iout1,2,3
#define FILTER_IOUTX_POLE   0x05                    // RC pole
#define FILTER_IOUTX_GAIN   0x02                    // scale up
#define FILTER_IOUTX_SCALE  4 //(FILTER_IOUTX_POLE + FILTER_IOUTX_GAIN)

// filter for vout_adj
#define FILTER_VOUT_ADJ_POLE    0x08                    // RC pole
#define FILTER_VOUT_ADJ_GAIN    0x02                    // scale up
#define FILTER_VOUT_ADJ_SCALE   7 //(FILTER_VOUT_ADJ_POLE + FILTER_VOUT_ADJ_GAIN)

// filter for vout_adj
#define FILTER_VCAP_POLE        0x02                    // RC pole
#define FILTER_VCAP_GAIN        0x02                    // scale up
#define FILTER_VCAP_SCALE       (FILTER_VCAP_POLE + FILTER_VCAP_GAIN)

extern voltage_t voltage;
extern current_t current;
extern temperature_t temperature;
extern int32_t iout_avg;

extern int32_t vout_pot_adj_avg;
extern int32_t vout_pot_adj_filt_prev;

void analogA_init(void);
void analogA_process(void);
void analogB_init(void);
void analogB_process(void);
void vprog_process(void);
void vout_adjust_process(void);
int16_t cal_iprog2ioutcnt(int16_t iprog_cnt);

#endif /* ANALOG_H_ */
