/*
 * bootmode.c
 *
 *  Created on: May 27, 2021
 *      Author: ahugron
 */

#include "main.h"
#include "pmbus.h"
#include "state.h"
#include "flashInterface.h"
#include "bootmode.h"
#include "digital_io.h"

#ifdef O3_CODE
#pragma GCC optimize ("O3")
#endif

// for bootloading entry (shared memory)
bootloader_share_data_t bootloader_share_data;

void bootloader_init(void)
{
	// clear bootload shared memory
	bootloader_share_data.pwd0 = 0x00;
	bootloader_share_data.pwd1 = 0x00;
	bootloader_share_data.pwd2 = 0x00;
	bootloader_share_data.pwd3 = 0x00;
	bootloader_share_data.target_level = 0x00;
	bootloader_share_data.encryption_type = 0x00;
}

// buffer:
// buffer[0]..[3] 	-> PWD for Bootloader entry (lsb)
// buffer[4]		-> target_level
// buffer[5]		-> encryption_type
// buffer[6]		-> rfu
// buffer[7]		-> rfu
// will execute a software reset if valid command
uint8_t bootloader_entry(uint8_t *buffer, uint8_t size, uint8_t type)
{
	if(type == TYPE_WR)
	{
		if((size == 0x08u) && (buffer[0] == BOOT_ENTRY_0) && (buffer[1] == BOOT_ENTRY_1) && (buffer[2] == BOOT_ENTRY_2) && (buffer[3] == BOOT_ENTRY_3))
		{
			if((buffer[5] > 0x01u) || (buffer[4] > 0x30u))				// check encryption type (should not be more than 1 for now) and Target type (no more than 2 level)
			{
				pmbus_data.status_cml.bits.st_cml_inv_data = 1;			// wrong data received, set the pmbus status flag
			}
			else
			{
				if((pmbus_data.write_protect0 == 0x00u) && (buffer[6] == 0x00u) && (buffer[7] == 0x00u))	// rfu field should be 0
				{
					clear_system_reset_status();

					// bootloader mode code are correct, initialize shared memory to indicate that we want to do frw update
					bootloader_share_data.pwd0 = BOOT_ENTRY_0;
					bootloader_share_data.pwd1 = BOOT_ENTRY_1;
					bootloader_share_data.pwd2 = BOOT_ENTRY_2;
					bootloader_share_data.pwd3 = BOOT_ENTRY_3;
					bootloader_share_data.target_level = buffer[4];
					bootloader_share_data.encryption_type = buffer[5];
					bootloader_share_data.rfu0 = 0;
					bootloader_share_data.rfu1 = 0;

					// shutdown output to prepare to be in boot mode
					ISHARE_PROT_ON();									// disable external ishare signal
					state_llc_pwm_off();								// turn off llc pulses

					DisableGlobalIRQ();									// disable interrupts
					set_dsp_normal_run();
//	TBD				NVIC_SystemReset();									// software reset
					// should not go here, we just did a software reset
				}
			}
		}
		else
		{
			pmbus_data.status_cml.bits.st_cml_memory = 1;				// wrong data received, set the pmbus status flag
		}
	}
	return 0;
}
