/******************************************************************************
 *  File: digital_io.c
 *  Description: general IO function
 *  Author: Arnaud Hugron
 *  Date: 08/13/2015
 *****************************************************************************/
#include "main.h"
#include "setup.h"
#include "digital_io.h"
#include "pmbus.h"
#include "control.h"
#include "restart.h"
#include "primary.h"
#include "pri_comm.h"
#include "state.h"
#include "calibration.h"

#define PMBUS_ON_COUNTER 10
#define PMBUS_OFF_COUNTER 10

void io_init(void)
{
	SYNC_SIG_OFF();
//	CLEAR_OC_FAULT();
//	CLEAR_OV_FAULT();
//	CLEAR_SW_OV_FAULT();
}

#pragma CODE_SECTION(io_process, ".TI.ramfunc");
// executed every 1ms
void io_process(void)
{
#ifndef OPEN_LOOP
	// check pwm faults (OCP and OVP fault pins)
    if(IS_EXT_WDT_FAULT())
    {
#ifndef DISABLE_SAFETY_LATCH
        shutdown_event.bits.hw_fault = 1;                   // fault due to Ext WDT TBD AH
#endif
        pmbus_data.status_other.bits.st_ext_wdt = 1;
        pmbus_data.status_word.bits.sts_other = 1;
    }
    if(IS_HW_IMB_FAULT())
    {
#ifndef DISABLE_SAFETY_LATCH
        shutdown_event.bits.hw_fault = 1;                   // fault due to HW Imb Ioutx
#endif
        pmbus_data.status_other.bits.st_hw_imb = 1;
        pmbus_data.status_word.bits.sts_other = 1;
    }
    if(IS_CAP_OVP_FAULT())
    {
#ifndef DISABLE_SAFETY_LATCH
        shutdown_event.bits.hw_fault = 1;                   // fault due to cap ovp
#endif
        pmbus_data.status_other.bits.st_cap_ovp = 1;
        pmbus_data.status_word.bits.sts_other = 1;
    }
    if(IS_OVP_FAULT())
    {
        // normal output OVP
        shutdown_event.bits.pwm_fault_ovp = 1;              // pwm fault 1 (OVP), fixed by hardware
        pmbus_data.status_vout.bits.st_vout_ov = 1;
        pmbus_data.status_word.bits.sts_vout_ov = 1;
        pmbus_data.status_mfr_specific.bits.st_hw_ovp = 1;
    }
	if(IS_SW_OV_FAULT())
	{
		state_llc_pwm_off();									// PWM did SD automatically, set bridge in OFF state
		CLEAR_SW_OV_FAULT();									// clear pwm fault flag
		shutdown_event.bits.pwm_fault_user_ovp = 1;				// pwm fault 2 (OVP) set by DSP COMPARATOR 2 using internal DAC as reference, user define or function of your setting (variable, set by frw pmbus)
		pmbus_data.status_vout.bits.st_vout_ov = 1;
		pmbus_data.status_word.bits.sts_vout_ov = 1;
		pmbus_data.status_mfr_specific.bits.st_sw_ovp = 1;
	}
#else
	// open loop indication flags
    if(IS_EXT_WDT_FAULT())
    {
        pmbus_data.status_other.bits.st_ext_wdt = 1;
        pmbus_data.status_word.bits.sts_other = 1;
    }
    if(IS_HW_IMB_FAULT())
    {
        pmbus_data.status_other.bits.st_hw_imb = 1;
        pmbus_data.status_word.bits.sts_other = 1;
    }
    if(IS_CAP_OVP_FAULT())
    {
        pmbus_data.status_other.bits.st_cap_ovp = 1;
        pmbus_data.status_word.bits.sts_other = 1;
    }
    if(IS_OVP_FAULT())
    {
        // normal output OVP
        pmbus_data.status_vout.bits.st_vout_ov = 1;
        pmbus_data.status_word.bits.sts_vout_ov = 1;
        pmbus_data.status_mfr_specific.bits.st_hw_ovp = 1;
    }
#endif

	if(status.bits.sec_calibration_mode == 1u)
	{
		shutdown_event.all &= ~shutdown_event_mask.all;			// can only mask shutdown_event bits in calibration mode
	}

	// reset quick acf flag
	if(primary_status.bits.quick_acf == 1u)
	{
		if(reset_quick_acf++ > 800u)
		{
			primary_status.bits.quick_acf = 0;					// reset after 800ms
		}
	}
}

