/******************************************************************************
 *  File: flash.h
 *  Description:
 *  Author: Arnaud Hugron
 *  Date: 08/13/2015
 *****************************************************************************/
#ifndef FLASH_H_
#define FLASH_H_

//#include <MKV46F16_features.h>
#include "FlashAPI/F021_F28003x_C28x.h"

// Program Flash block information TBD
#define P_BLOCK_NUM     2                               //
#define P_SECTOR_SIZE   0x001000                        //
#define P_FLASH_SIZE    (P_SECTOR_SIZE * P_BLOCK_NUM)   //
#define PGM_SIZE_BYTE	2                               //FSL_FEATURE_FLASH_PFLASH_BLOCK_WRITE_UNIT_SIZE

#define FSL_FEATURE_FLASH_PFLASH_SECTION_CMD_ADDRESS_ALIGMENT 1  // TBD

#define READ_NORMAL_MARGIN	0x00
#define READ_USER_MARGIN    0x01
#define READ_FACTORY_MARGIN 0x02

// Flash hardware algorithm operation commands
#define FTFx_VERIFY_BLOCK               0x00U
#define FTFx_VERIFY_SECTION             0x01U
#define FTFx_PROGRAM_CHECK              0x02U
#define FTFx_READ_RESOURCE              0x03U
#define FTFx_PROGRAM_LONGWORD           0x06U
#define FTFx_PROGRAM_PHRASE             0x07U
#define FTFx_ERASE_BLOCK                0x08U
#define FTFx_ERASE_SECTOR               0x09U
#define FTFx_PROGRAM_SECTION            0x0BU
#define FTFx_VERIFY_ALL_BLOCK           0x40U
#define FTFx_READ_ONCE                  0x41U
#define FTFx_PROGRAM_ONCE               0x43U
#define FTFx_ERASE_ALL_BLOCK            0x44U
#define FTFx_SECURITY_BY_PASS           0x45U
#define FTFx_PFLASH_SWAP                0x46U
#define FTFx_ERASE_ALL_BLOCK_UNSECURE   0x49U
#define FTFx_PROGRAM_PARTITION          0x80U
#define FTFx_SET_EERAM                  0x81U

#define FTFx_SSD_FSTAT_ERROR_BITS       //((FTFA_FSTAT_FPVIOL_MASK | FTFA_FSTAT_ACCERR_MASK | FTFA_FSTAT_RDCOLERR_MASK) | FTFA_FSTAT_MGSTAT0_MASK)

typedef union
{
	uint16_t all;
    struct
    {
		unsigned write_cal_static		:1;
		unsigned write_cal_dynamic_factory:1;
		unsigned write_cal_dynamic		:1;
		unsigned rfu0  					:1;

		unsigned erase_runtime_sec0		:1;
		unsigned erase_runtime_sec1		:1;
		unsigned erase_dynamic_sec0		:1;
		unsigned erase_dynamic_sec1		:1;

		unsigned write_flash			:1;
	    unsigned erase_flash			:1;

    }bits;
} flash_flags_t;

#define FLASH_INIT  				0u
#define FLASH_ERASE_SECTOR 			1u
#define FLASH_WRITE_32BITS_FLASH 	2u
#define FLASH_DONE 					3u

extern flash_flags_t flash_flags;

void flash_init(void);
void flash_process(void);
uint16_t FlashExecuteSequence(void);
void FlashProgram(uint32_t dest, uint32_t size, uint8_t *pData);
void FlashProgramCheck(uint32_t dest, uint32_t size, uint8_t *pExpectedData, uint32_t *pFailAddr);
void FlashProgram32bits(uint32_t dest, uint32_t Data);
void FlashEraseSector(uint32_t dest);
void FlashVerifySection(uint32_t dest, uint16_t number);

void set_dsp_normal_run(void);
void set_dsp_high_speed_run(void);

#endif /* FLASH_H_ */
