/* ###################################################################
**     Filename    : main.c
**     Project     : frw
**     Processor   : MKV46F256VLH16
**     Version     : Driver 01.01
**     Compiler    : GNU C Compiler
**     Date/Time   : 2015-12-18, 13:12, # CodeGen: 0
**     Abstract    :
**         Main module.
**         This module contains user's application code.
**     Settings    :
**     Contents    :
**         No public methods
**
** ###################################################################*/
/*!
** @file main.c
** @version 01.01
** @brief
**         Main module.
**         This module contains user's application code.
*/
/*!
**  @addtogroup main_module main module documentation
**  @{
*/
/* MODULE main */

#if CPU_INIT_CONFIG
  #include "Init_Config.h"
#endif
/* User includes (#include below this line is not maintained by Processor Expert) */
#include "main.h"
#include "main_init.h"
#include "pmbus.h"
#include "pmbus_driver.h"
#include "timer.h"
#include "control.h"
#include "pri_comm.h"
#include "analog.h"
#include "temperature.h"
#include "state.h"
#include "restart.h"
#include "fan.h"
#include "calibration.h"
#include "flashInterface.h"
#include "primary.h"
#include "preload.h"
#include "power.h"
#include "digital_io.h"

#ifdef MODBUS_SUPPORT
#include "modbus_driver.h"
#endif
#ifdef SCPI_SUPPORT
#include "scpi.h"
#endif
#ifdef CANBUS_SUPPORT
#include "can_driver.h"
#include "canopen_sdo.h"
#endif

/*lint -save -e970*/
int main(void);

volatile uint32_t ePWM[] ={0, myEPWM1_BASE, myEPWM2_BASE, myEPWM3_BASE, myEPWM4_BASE};

int main(void)
/*lint -restore */
{
  /* Write your code here */
     calibration_init();
    control_init();
    dsp_init();
    control_pwm_init();
	timer_init();
	flash_init();
    io_init();
	pmbus_init();
	state_init();


	CONTROL_SET_LDOK();                                             // set LDOK, update PWM registers at next reload

	EnableGlobalIRQ();

	EPWM_selectPeriodLoadEvent(EPWM1_BASE, EPWM_SHADOW_LOAD_MODE_SYNC);
	EPWM_selectPeriodLoadEvent(EPWM2_BASE, EPWM_SHADOW_LOAD_MODE_SYNC);
	EPWM_selectPeriodLoadEvent(EPWM3_BASE, EPWM_SHADOW_LOAD_MODE_SYNC);

	pmbus_data.debugParam0 = 455;   // equivalent to 198KHz
	pmbus_data.debugParam1 = 416;   // equivalent to 150KHz
	open_loop_state = 3;

	for(;;)
	{
		timer_process();
	}
}

