/******************************************************************************
 *  File: main.h
 *  Description: main header
 *  Author: Arnaud Hugron
 *  Date: 12/13/2015
 *****************************************************************************/
#ifndef MAIN_H_
#define MAIN_H_

#include "setup.h"

#define TI_C2000    1
//#define NXP_KINETIS 1

#ifdef TI_C2000
// TI main defined
#include "board.h"
#include "sfo_v8.h"
#include "f28003x_device.h"

#define FAST_PERIPHERAL_CLOCK   120000000ul   // clock speed for fast peripheral
#define BUS_PERIPHERAL_CLOCK    120000000ul   // bus/flash clock
#define PIT_CLOCK               120000000ul   // PIT timer

#endif

#ifdef NXP_KINETIS
// NXP Kinetis main define
#include <MKV46F16_extension.h>
#include "digital_io.h"

#define FAST_PERIPHERAL_CLOCK	84000000u	// clock speed for fast peripheral
#define BUS_PERIPHERAL_CLOCK	21000000u	// bus/flash clock
#define PIT_CLOCK 				21000000u	// PIT timer is running at 21MHz
#endif

//****************************************************************************
// Product code mask
// bit15-14: profile
// bit 13-11: rfu
// bit 10-9: Input Line configuration
// bit 8-7: phase number
// bit 6-0: Nominal Voltage

#define MFR_PRODUCT_CODE_PROFILE_MASK 	0xC000	// Profile mask
#define MFR_PRODUCT_CODE_PROFILE_STD	0x0000		// standard profile
#define MFR_PRODUCT_CODE_PROFILE_LOW	0x8000		// low profile

#define MFR_PRODUCT_CODE_LINE_MASK		0x0600	// Line mask
#define MFR_PRODUCT_CODE_LINE_HL		0x0000		// high and low line
#define MFR_PRODUCT_CODE_LINE_LOW		0x0200		// low line only
#define MFR_PRODUCT_CODE_LINE_HIGH		0x0400		// high line only
#define MFR_PRODUCT_CODE_LINE_RFU		0x0600		// RFU

#define MFR_PRODUCT_CODE_PHASE_MASK		0x0180	// #Phase or PFC# mask
#define MFR_PRODUCT_CODE_PHASE_3		0x0000
#define MFR_PRODUCT_CODE_PHASE_1		0x0100
#define MFR_PRODUCT_CODE_PHASE_2		0x0080

#define MFR_PRODUCT_CODE_VOLTAGE_MASK	0x007F	// Voltage mask
#define MFR_PRODUCT_CODE_VOLTAGE_24V	0x0002
#define MFR_PRODUCT_CODE_VOLTAGE_48V	0x0005
#define MFR_PRODUCT_CODE_VOLTAGE_60V	0x0006
#define MFR_PRODUCT_CODE_VOLTAGE_80V	0x0008
#define MFR_PRODUCT_CODE_VOLTAGE_100V	0x000A
#define MFR_PRODUCT_CODE_VOLTAGE_200V	0x0014
#define MFR_PRODUCT_CODE_VOLTAGE_400V   0x0028
#define MFR_PRODUCT_CODE_VOLTAGE_800V   0x0050

//****************************************************************************
#ifndef FALSE
#define FALSE 0
#endif

#ifndef TRUE
#define TRUE 1
#endif

//typedef int bool_t;
typedef char char_t;
typedef int int_t;
typedef double double_t;

//typedef float32_t float_t;

// Read/Write/Set/Clear Operation Macros
#define GET_BIT_0_7(value)              ((uint8_t)((value) & 0xFFU))
#define GET_BIT_8_15(value)             ((uint8_t)(((value)>>8) & 0xFFU))
#define GET_BIT_16_23(value)            ((uint8_t)(((value)>>16) & 0xFFU))
#define GET_BIT_24_31(value)            ((uint8_t)((value)>>24))

static inline void DisableGlobalIRQ(void)
{
    DINT;
}

static inline void EnableGlobalIRQ(void)
{
    EINT;
}

#endif /* MAIN_H */
