//
// Included Files
//

#include "main.h"

#ifdef TI_C2000
#include "board.h"
#include "sfo_v8.h"
#include "control.h"

int MEP_ScaleFactor; // Global variable used by the SFO library
                     // Result can be used for all HRPWM channels
                     // This variable is also copied to HRMSTEP
                     // register by SFO() function.

void error(void);

void dsp_init(void)
{
    uint16_t status = SFO_INCOMPLETE;

    // Initialize device clock and peripherals
    Device_init();

    // Disable pin locks and enable internal pull ups.
    Device_initGPIO();

    // Initialize PIE and clear PIE registers. Disables CPU interrupts.
    Interrupt_initModule();

    // Initialize the PIE vector table with pointers to the shell Interrupt
    // Service Routines (ISR).
    Interrupt_initVectorTable();

    // Calling SFO() updates the HRMSTEP register with calibrated MEP_ScaleFactor.
    // HRMSTEP must be populated with a scale factor value prior to enabling
    // high resolution period control.
    while(status == SFO_INCOMPLETE)
    {
        status = SFO();
        if(status == SFO_ERROR)
        {
            error();   // SFO function returns 2 if an error occurs & # of MEP
        }              // steps/coarse step exceeds maximum of 255.
    }

    // Disable sync(Freeze clock to PWM as well)
    SysCtl_disablePeripheral(SYSCTL_PERIPH_CLK_TBCLKSYNC);

    mask_pwm_output();
    // Initialize EPWM GPIOs and change XBAR inputs from using GPIO0
    Board_init();

    // Enable sync and clock to PWM
    SysCtl_enablePeripheral(SYSCTL_PERIPH_CLK_TBCLKSYNC);

    ERTM;       //realtime interrupt (DBGM)

    // init ADCA for VOUT oversampling
    ADC_enableInterrupt(myADC0_BASE, ADC_INT_NUMBER1);  // Enable ADC interrupts, set for continuous SOC
    HWREGH(myADC0_BASE + ADC_O_INTFLGCLR) = 0x0001;     // Clear all interrupts flags(INT1), INT1 will trigger new SOC
    HWREGH(myADC0_BASE + ADC_O_SOCFRC1) = 0x001F;       // Software force start SOC0 to SOC4, continuous conversion for ADCA, other ADCs are from PWMs trigger to make less noisy and away from edges
}

//
// error - Halt debugger when called
//
void error(void)
{
    ESTOP0;         // Stop here and handle error
}

#endif
