/*
 * preload.h
 *
 *  Created on: Mar 30, 2016
 *      Author: ahugron
 */
#ifndef PRELOAD_H_
#define PRELOAD_H_

#include "analog.h"
#include "setup.h"

#ifdef NXP
typedef struct
{
  __IO uint16_t VAL;
} REG16_t;
#define DAC0_DATA_BASE      (0x4003F000u)    // use DAC0 for preload control
#define PRELOAD_DATA        (((REG16_t *)DAC0_DATA_BASE)->VAL)
#endif

#define PRELOAD_DATA       	(DacaRegs.DACVALS.bit.DACVALS)

typedef struct
{
    uint16_t preload_ctrl;
    uint16_t preload_ctrl_min;
    uint16_t preload_energy;
    uint16_t preload_energy_max;
	uint16_t preload_fan_offset_clear_cnt;
	int16_t  preload_voltage_offset;
    uint16_t preload_max_diff_timer;
    int16_t preload_cnt;

    int32_t  preload_int;
    uint32_t preload_energy_total;
    uint32_t preload_energy_limit;
    uint16_t preload_ctrl_max;
}preload_t;

// Preload
#ifdef HPT5K_48V
#define PRELOAD_FS	    		(1697l)		// max I for preload in 1/100A, same as 60v
#define PRELOAD_MAX				PRELOAD_I_cA_TO_CNT(1542)	// in centi A
#define PRELOAD_LOW_VOUT		PRELOAD_I_cA_TO_CNT(300)
#elif HPT5K_60V
#define PRELOAD_FS	    		(1697l)		// max I for preload 16.97A in 1/100A
#define PRELOAD_MAX				PRELOAD_I_cA_TO_CNT(1542)
#define PRELOAD_LOW_VOUT		PRELOAD_I_cA_TO_CNT(300)
#elif HPT5K_80V
#define PRELOAD_FS	    		(778l)		// max I for preload in 1/100A (same caps as 100v but less voltage)
#define PRELOAD_MAX				PRELOAD_I_cA_TO_CNT(708)
#define PRELOAD_LOW_VOUT		PRELOAD_I_cA_TO_CNT(300)
#elif HPT5K_100V
#define PRELOAD_FS	    		(990l)		// max I for preload 9.9A in 1/100A
#define PRELOAD_MAX				PRELOAD_I_cA_TO_CNT(900)
#define PRELOAD_LOW_VOUT		PRELOAD_I_cA_TO_CNT(300)
#elif HPT5K_200V
#define PRELOAD_FS	    		(504l)		// max I for preload 5.04A in 1/100A
#define PRELOAD_MAX				PRELOAD_I_cA_TO_CNT(458)
#define PRELOAD_LOW_VOUT		PRELOAD_I_cA_TO_CNT(300)
#elif HPT5K_400V
#define PRELOAD_FS              (170l)      // max I for preload in 1/100A
#define PRELOAD_MAX             PRELOAD_I_cA_TO_CNT(130)
#define PRELOAD_LOW_VOUT        PRELOAD_I_cA_TO_CNT(30 /*60*/)
#elif HPT5K_800V
#define PRELOAD_FS              (80l)      // max I for preload in 1/100A
#define PRELOAD_MAX             PRELOAD_I_cA_TO_CNT(60)
#define PRELOAD_LOW_VOUT        PRELOAD_I_cA_TO_CNT(30)
#endif

#define PRELOAD_CNT_FS  		(4095) 								// 12 bits DAC
#define PRELOAD_I_cA_TO_CNT(i)  (((int32_t)i * PRELOAD_CNT_FS) / PRELOAD_FS)		// in centi A

#define PRELOAD_ACTIVATION_VOLTAGE		(VOUT_PERCENTAGE_TO_COUNT(4))	// start to activate preload if Vout is more than x above voltage.u_ref
#define PRELOAD_DEACTIVATION_MAX_DIFF	(VOUT_PERCENTAGE_TO_COUNT(19))	// start to deactivate preload if difference between vref and output is more that %

#define PRELOAD_CYCLE					4800	// 1.2s, calculate dissipation every 1.2s
#define PRELOAD_FAULT_TIME				(PRELOAD_CYCLE - 140)	// 35ms fault check

#ifdef HPT5K_400V || HPT5K_800V
#define PRELOAD_MAX_DISSIPATION 		530u
#define PRELOAD_MAX_DISSIPATION_HV 		265u
#define PRELOAD_MAX_DISSIPATION_DELAY	40u		// 10ms (250us tick)
#else
#define PRELOAD_MAX_DISSIPATION         405u
#define PRELOAD_MAX_DISSIPATION_HV      202u
#define PRELOAD_MAX_DISSIPATION_DELAY   40u     // 10ms (250us tick)
#endif


#define PRELOAD_INTEGRATOR_SHIFT	6u
#define PRELOAD_INTEGRATOR_MIN		0l
#define PRELOAD_INTEGRATOR_MAX		(PRELOAD_MAX << PRELOAD_INTEGRATOR_SHIFT)

// J = P * T
// P = U * I
// 3W = adc * 123 / 32760   *   DAC * 9.9 / 4095
// DAC = (3W * 32760 * 4095) / (adc * 123 * 9.9)
#define CONSTANT_PRELOAD_POWER	4l		// constant preload power for low voltage
// (constant power = 3w, preload is 9.9A at DAC=4095)-> preload DAC = (3w * ADC_VSENSE_CNT_FS * 4095) / (ADC_VSENSE_FS * 9.9A) = 328556, +7 for 5mV offset
#define PRELOAD_GAIN (((CONSTANT_PRELOAD_POWER * ADC_VSENSE_CNT_FS * PRELOAD_CNT_FS) / (ADC_VSENSE_FS * PRELOAD_FS)) * 100l)

#define MAX_PRELOAD_POWER 600l
#define MAX_PRELOAD_GAIN (((MAX_PRELOAD_POWER * ADC_VSENSE_CNT_FS * 100l) / (ADC_VSENSE_FS * PRELOAD_FS))  * PRELOAD_CNT_FS)

extern preload_t preload;
extern int16_t max_vout;

void preload_init(void);
void preload_process(void);

#endif /* PRELOAD_H_ */
