/******************************************************************************
 *  File: pri_comm.c
 *  Description: primary communication function
 *  Author: Arnaud Hugron
 *  Date: 08/13/2015
 ****************************************************************************/
#include "main.h"
#include "setup.h"
#include "pri_comm.h"
#include "pmbus.h"
#include "calibration.h"
#include "primary.h"
#include "digital_io.h"
#include "fan.h"
#include "control.h"
#include "timer.h"
#include "pmbus_driver.h"


#define UART_BUFFER_SIZE 32u	// rolling circular buffer, be careful if changing size, need to change also buffer size mask

static /*__attribute__ ((section(".m_data_2")))*/ uint8_t uart_buffer[UART_BUFFER_SIZE];    		// uart buffer

static uint8_t uart_cmd;
static uint8_t uart_data;
static uint8_t uart_crc;
static uint8_t *uart_buffer_ptr;     	// pointer on data structure where we copy the received data from primary if crc ok or structure that we want to sent back to primary
static uint8_t uart_buffer_size;       	// size of data received or to transmit
//static uint8_t uart_rx_size;         	// size of data to received
static uint8_t uart_buffer_index;      	// index in rx/tx buffer
static pfc_info_t *pfc_info_ptr;
static pfc_data_t *pfc_data_ptr;

enum UART_PRI_STATE
{
	UART_PRI_STATE_IDLE = 0u,
	UART_PRI_STATE_TX_READ_CMD,
	UART_PRI_STATE_TX_WRITE_CMD,
	UART_PRI_STATE_TX_DATA,
	UART_PRI_STATE_WAIT_RX_DATA,
	UART_PRI_STATE_TX_READ_SEND_CMD_CRC
};

static enum UART_PRI_STATE uart_pri_state;

/*__attribute__ ((section(".m_data_2")))*/ pfc_info_t pfc_info1;
/*__attribute__ ((section(".m_data_2")))*/ pfc_info_t pfc_info2;
/*__attribute__ ((section(".m_data_2")))*/ pfc_info_t pfc_info3;
/*                                      */
/*__attribute__ ((section(".m_data_2")))*/ pfc_data_t pfc_data1;
/*__attribute__ ((section(".m_data_2")))*/ pfc_data_t pfc_data2;
/*__attribute__ ((section(".m_data_2")))*/ pfc_data_t pfc_data3;
/*                                      */
/*__attribute__ ((section(".m_data_2")))*/ sec_comm_err_t sec_comm_err1;
/*__attribute__ ((section(".m_data_2")))*/ sec_comm_err_t sec_comm_err2;
/*__attribute__ ((section(".m_data_2")))*/ sec_comm_err_t sec_comm_err3;
/*__attribute__ ((section(".m_data_2")))*/ sec_comm_err_t *sec_comm_err;		// pointer on the current secondary communication error structure

static void pri_comm_init_data_pfc1(void);
static void pri_comm_init_data_pfc2(void);
static void pri_comm_init_data_pfc3(void);

uint8_t pfc_adj1;					// 50% duty cycle by default (0 -> 255)
uint8_t pfc_adj2;
uint8_t pfc_adj3;

runtime_t runtime;
uint8_t pri_update_counter;

secondary_status_t secondary_status;
pri_comm_priority_cmd_t pri_comm_priority_cmd;
uint16_t reset_quick_acf;

// internal functions
static void pri_comm_priority_command(void);
static void pri_comm_init_info_pfc(void);
static void frame_error_timer_restart(void);

#define STD_PRI_CMD_INTERVAL	9u
#define FAST_PRI_CMD_INTERVAL	1u					// 20ms interval, about 60ms period for each PFC cmd, do not get pfc_info in this case

//******************************************************************
// main function
//******************************************************************
void pri_comm_init_process(void)
{

}

// execute this routine every 10ms
// will send command for each PFC in 100ms interval to get status and data from primary
void pri_comm_command_process(void)
{

}

#pragma CODE_SECTION(pri_comm_tx_process, ".TI.ramfunc");
/*__attribute__ ((section(".mydata")))*/ void pri_comm_tx_process(void)
{

}

inline void frame_error_timer_restart(void)
{
	// timer of 80us
    TIMER_BRK_CLEAR();
}

#pragma CODE_SECTION(pri_comm_rx_process, ".TI.ramfunc");
/*__attribute__ ((section(".mydata")))*/ void pri_comm_rx_process(void)
{
}

static void pri_comm_init_data_pfc1(void)
{
	pfc_data1.vin = 0;
	pfc_data1.dc_bus = 0;
	pfc_data1.temperature_c = 0;
	pfc_data1.dc_bus_ref = 0;
	pfc_data1.fault.all = 0;
	pfc_data1.status.all = 0;
	pfc_data1.status.bits.ac_loss = 1;
	pfc_data1.fault.bits.ac_uv = 1;
	pfc_data1.fault.bits.pfc_uv = 1;
}

static void pri_comm_init_data_pfc2(void)
{
	pfc_data2.vin = 0;
	pfc_data2.dc_bus = 0;
	pfc_data2.temperature_c = 0;
	pfc_data2.dc_bus_ref = 0;
	pfc_data2.fault.all = 0;
	pfc_data2.status.all = 0;
	pfc_data2.status.bits.ac_loss = 1;
	pfc_data2.fault.bits.ac_uv = 1;
	pfc_data2.fault.bits.pfc_uv = 1;
}

static void pri_comm_init_data_pfc3(void)
{
	pfc_data3.vin = 0;
	pfc_data3.dc_bus = 0;
	pfc_data3.temperature_c = 0;
	pfc_data3.dc_bus_ref = 0;
	pfc_data3.fault.all = 0;
	pfc_data3.status.all = 0;
	pfc_data3.status.bits.ac_loss = 1;
	pfc_data3.fault.bits.ac_uv = 1;
	pfc_data3.fault.bits.pfc_uv = 1;
}

//******************************************************************
// local function
//******************************************************************
static void pri_comm_priority_command(void)
{

}

static void pri_comm_init_info_pfc(void)
{
	pfc_info1.frw_version = 0;
	pfc_info1.pfc_state = 0;
	pfc_info1.frame_error_cnt = 0;
	pfc_info1.overrun_cnt = 0;
	pfc_info1.pkt_crc_error_cnt = 0;
	pfc_info1.pkt_timeout_cnt = 0;
	pfc_info1.relay_close_cnt = 0;					// get that from EEPROM/flash
	pfc_info1.last_pfc_fault = 0;
	pfc_info1.rfu = 0;

	pfc_info2.frw_version = 0;
	pfc_info2.pfc_state = 0;
	pfc_info2.frame_error_cnt = 0;
	pfc_info2.overrun_cnt = 0;
	pfc_info2.pkt_crc_error_cnt = 0;
	pfc_info2.pkt_timeout_cnt = 0;
	pfc_info2.relay_close_cnt = 0;					// get that from EEPROM/flash
	pfc_info2.last_pfc_fault = 0;
	pfc_info2.rfu = 0;

	pfc_info3.frw_version = 0;
	pfc_info3.pfc_state = 0;
	pfc_info3.frame_error_cnt = 0;
	pfc_info3.overrun_cnt = 0;
	pfc_info3.pkt_crc_error_cnt = 0;
	pfc_info3.pkt_timeout_cnt = 0;
	pfc_info3.relay_close_cnt = 0;					// get that from EEPROM/flash, or save into PFC EEPROM MCU
	pfc_info3.last_pfc_fault = 0;
	pfc_info3.rfu = 0;
}

void pri_comm_check_comm_timeout(void)
{

}
