/******************************************************************************
 *  File: restart.h
 *  Description: fault restart state
 *  Author: Arnaud Hugron
 *  Date: 08/13/2015
 ****************************************************************************/

#ifndef RESTART_H_
#define RESTART_H_

#define RESTART_STATE_IDLE 0u
#define RESTART_STATE_UV 1u
#define RESTART_STATE_OCP 2u
#define RESTART_STATE_OCPX 3u
#define RESTART_STATE_OVP 4u
#define RESTART_STATE_INPUT_FAULT 5u
#define RESTART_STATE_FAN_OTP_FAULT 6u
#define RESTART_STATE_PRICOMM_FAULT 7u
#define RESTART_STATE_INPUT_OV_FAULT 8u
#define RESTART_STATE_WAIT_FOR_TIMER 9u
#define RESTART_STATE_WAIT_FOR_TIMER1 10u
#define RESTART_STATE_STARTING 11u
#define RESTART_STATE_WAIT_FOR_CONTROLLER 12u
#define RESTART_STATE_SHORT 13u
#define RESTART_STATE_DELAY 14u

typedef struct
{
	uint8_t state;
	uint8_t reset_timer_s;
	uint16_t wait_timer_10ms;

	uint8_t uv_retry_counter;
	uint8_t ocp_retry_counter;
	uint8_t ovp_retry_counter;
	uint8_t ocpx_retry_counter;
	uint8_t input_retry_counter;
	uint8_t fan_otp_retry_counter;
	uint8_t pricomm_retry_counter;
	uint8_t input_ov_retry_counter;
	uint8_t delay_retry_counter;

	uint8_t uv_max_retry;
	uint8_t ocp_max_retry;
	uint8_t ovp_max_retry;
	uint8_t ocpx_max_retry;
	uint8_t input_max_retry;
	uint8_t fan_otp_max_retry;
	uint8_t pricomm_max_retry;
	uint8_t input_ov_max_retry;
} restart_t;

typedef union
{
	uint16_t all;
	struct
	{
		unsigned  restart_request			:1;
		unsigned  rfu0						:1;
		unsigned  input_restart_request		:1;
		unsigned  input_ov_restart_request	:1;

		unsigned  uv_restart_request		:1;
		unsigned  ocp_restart_request		:1;
		unsigned  ovp_restart_request		:1;
		unsigned  fan_otp_restart_request	:1;

		unsigned  pricomm_restart_request	:1;
		unsigned  ocpx_restart_request		:1;
		unsigned  short_restart_request		:1;
		unsigned  delay_restart_request		:1;
	} bits;
} restart_flags_t;

#define RESTART_RESET_S 					120	 	// 120 seconds
#define OVP_MAX_RESTART_RETRIES				0

#define OVP_RESTART_DELAY_10_MS 			400  	// 4 seconds
#define INPUT_RESTART_DELAY_10_MS 	 		600		// 6 seconds
#define INPUT_OV_RESTART_DELAY_10_MS 		600		// 6 seconds
#define FAN_OTP_RESTART_DELAY_10_MS 	 	1000	// 10 seconds
#define PRICOMM_RESTART_DELAY_10_MS			600		// 6 seconds
#define SHORT_RESTART_DELAY_10_MS 			1000  	// 10 seconds
#define DELAY_RESTART_DELAY_10_MS 			40		//190  	// 1.9s second

extern restart_t restart;
extern restart_flags_t restart_flags;

#define	RESTART_UV_REQUEST()		{restart_flags.bits.uv_restart_request=1;}
#define	RESTART_SHORT_REQUEST()		{restart_flags.bits.short_restart_request=1;}
#define	RESTART_OCP_REQUEST()		{restart_flags.bits.ocp_restart_request=1;}
#define	RESTART_OCPX_REQUEST()		{restart_flags.bits.ocpx_restart_request=1;}
#define	RESTART_OVP_REQUEST()		{restart_flags.bits.ovp_restart_request=1;}
#define	RESTART_INPUT_REQUEST()		{restart_flags.bits.input_restart_request=1;}
#define	RESTART_INPUT_OV_REQUEST()	{restart_flags.bits.input_ov_restart_request=1;}
#define	RESTART_FAN_OTP_REQUEST()	{restart_flags.bits.fan_otp_restart_request=1;}
#define	RESTART_PRICOMM_REQUEST()	{restart_flags.bits.pricomm_restart_request=1;}
#define	RESTART_DELAY_REQUEST()		{restart_flags.bits.delay_restart_request=1;}

void restart_init(void);
void restart_clear_fault(void);
void restart_process(void);

#endif /* RESTART_H_ */
