/******************************************************************************
 *  File: state.h
 *  Description:
 *  Author: Arnaud Hugron
 *  Date: 08/13/2015
 *****************************************************************************/
#ifndef STATE_H_
#define STATE_H_

#include "power.h"

#define STATE_INIT 				0u
#define STATE_OFF 				1u
#define STATE_CURRENT_WALKIN	2u
#define STATE_VOLTAGE_WALKIN	3u
#define STATE_STARTUP_STAGE		4u
#define STATE_ON				5u
#define STATE_CALIBRATION		6u
#define STATE_TEST_MODE			7u

typedef struct
{
	uint8_t state;
} state_t;

#define TICKS_PER_1MS	4

#define VOLTAGE_STEP_TICK_PER_MS TICKS_PER_1MS
#define CURRENT_STEP_TICK_PER_MS 1

//#define I_SLEW_STEP 			(ISENSE_PERCENTAGE_TO_COUNT(1)/10)		// 0.1% step
//#define I_SLEW_COLD_STEP		(ISENSE_PERCENTAGE_TO_COUNT(1)/32)		// 0.032% step

#define I_SLEW_COLD_STEP        (ISENSE_TO_COUNT(MFR_IOUT_NOMINAL)/(1200 * CURRENT_STEP_TICK_PER_MS))                   // param in ms
#define I_SLEW_DEFAULT_STEP     (ISENSE_TO_COUNT(MFR_IOUT_NOMINAL)/(RAMP_CURRENT_MIN * CURRENT_STEP_TICK_PER_MS))       // param in ms

#define V_SLEW_UP_STEP          (VSENSE_TO_COUNT(MFR_VOUT_NOMINAL)/(35*TICKS_PER_1MS))      // 35ms ramp
#define V_SLEW_DEFAULT_STEP     (VSENSE_TO_COUNT(MFR_VOUT_NOMINAL)/(RAMP_VOLTAGE_MIN * VOLTAGE_STEP_TICK_PER_MS))       // ms ramp
#define V_SLEW_UP_CL_INC        (VSENSE_TO_COUNT(MFR_VOUT_NOMINAL)/(150 * VOLTAGE_STEP_TICK_PER_MS))    // increase OC limit if ramp up faster than this
#define V_SLEW_COLD_STEP        (VSENSE_TO_COUNT(MFR_VOUT_NOMINAL)/(2000*TICKS_PER_1MS))    // 2s
#define V_SLEW_FAULT_STEP       (VSENSE_TO_COUNT(MFR_VOUT_NOMINAL)/(RAMP_VOLTAGE_FAULT_MIN * VOLTAGE_STEP_TICK_PER_MS)) // ms min ramp during fault condition

//#define V_SLEW_DOWN_STEP 		(VSENSE_TO_COUNT(MFR_VOUT_NOMINAL)/(35*TICKS_PER_1MS))		// 35ms ramp TBD remove
//#define V_SLEW_STEP_MIN 		(VSENSE_TO_COUNT(MFR_VOUT_NOMINAL)/(35*TICKS_PER_1MS))		// 35ms min ramp
//#define V_SLEW_STEP_MAX 		(VSENSE_TO_COUNT(MFR_VOUT_NOMINAL)/(1000*TICKS_PER_1MS))	// 1000ms max ramp

#define SOFT_START_STEP_MIN		(VOUT_PERCENTAGE_TO_COUNT(18))								// use soft start if difference is more than x% of nominal

#define EARLY_WARNING_DELAY		(10*TICKS_PER_1MS)			// early warning SD for most of the power failure

// Calibration state Command
#define STATE_CAL_DCBUS_INIT	1
#define STATE_CAL_DCBUS_CAL		2
#define STATE_CAL_DCBUS_DONE	3

#define CAL_DCBUS_INIT_DELAY	(500 * TICKS_PER_1MS)	// ms (cal process is every 250us)
#define CAL_DCBUS_RETRY			35						// should be CAL_DCBUS_MAX_OFS / 2 (step of 2)
#define CAL_DCBUS_CAL_DELAY		(400 * TICKS_PER_1MS)	// ms
#define CAL_DCBUS_MAX_OFS		70

extern state_t state;
extern uint16_t ramp_up;
extern uint8_t ramp_up_delay;
extern uint8_t state_calibration;
extern int16_t calibration_delay;

void state_init(void);
void state_process(void);
void state_init_process(void);
void state_off_process(void);
void state_goto_walkin(void);
void state_voltage_walking_process(void);
void state_current_walking_process(void);
void state_goto_on(void);
void state_run_process(void);
void state_llc_pwm_off(void);
void state_llc_pwm_on(void);
void state_calibration_process(void);
void state_test_mode_process(void);

void voltage_loop_coefficient(void);


#endif /* STATE_H_ */
